#[repr(u8)]pub enum FreqmectrlWMeasureInProgress {
FORCE_TERMINATE = 0,
INITIATE_A_FREQME_CYCLE = 1,
}Variants
FORCE_TERMINATE = 0
Force Terminate. Forces the termination of any measurement cycle currently in progress and resets RESULT or just resets RESULT if in idle.
INITIATE_A_FREQME_CYCLE = 1
Initiates Measurement Cycle. Initiates frequency or pulse width measurement process. Hardware clears the MEASURE_IN_PROGRESS bit when the measurement cycle completes. A new measurement starts if there is an active measurement in progress.
Implementations