nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

PulseMode

Enum PulseMode 

#[repr(u8)]
pub enum PulseMode { FREQ_ME_MODE = 0, PULSE_ME_MODE = 1, }

Variants



FREQ_ME_MODE = 0

Frequency Measurement Mode. FREQMECTRL works in a Frequency Measurement mode. Once the measurement starts (real count start is aligned at rising edge arrival on reference clock), the target counter increments by the target clock until the reference counter running by the reference clock reaches the count end point selected by REF_SCALE.



PULSE_ME_MODE = 1

Pulse Width Measurement mode. FREQMECTRL works in a Pulse Width Measurement mode, measuring the high or low period of reference clock input selected by PULSE_POL. The target counter starts incrementing by the target clock once a corresponding trigger edge (rising edge for high period measurement and falling edge for low period) occurs.

Implementations

Source

impl PulseMode

pub const fn from_bits(val: u8) -> PulseMode

pub const fn to_bits(self) -> u8