#[repr(u8)]pub enum PulsePol {
HIGH_PERIOD = 0,
LOW_PERIOD = 1,
}Variants
HIGH_PERIOD = 0
High Period. High period of reference clock is measured in Pulse Width Measurement mode triggered by the rising edge on the reference clock input.
LOW_PERIOD = 1
Low Period. Low period of reference clock is measured in Pulse Width Measurement mode triggered by the falling edge on the reference clock input.
Implementations